@@ -18,15 +18,13 @@ from plotly.subplots import make_subplots
 
 from typing import List, Tuple, Callable, Any, Sequence, Dict, Optional
 import traitlets
-from pyqstrat.pq_utils import bootstrap_ci, np_bucket, get_paths, get_child_logger
-
+from pyqstrat.pq_utils import bootstrap_ci, np_bucket, get_child_logger
 
 # Local Imports
 ROOT_DIR = os.path.join(sys.path[0])
 sys.path.insert(1, ROOT_DIR)
 
 # Constants and Globals
-_paths = get_paths('..')
 _logger = get_child_logger(__name__)
 
 DEFAULT_PLOTLY_COLORS = ['rgb(31, 119, 180)', 'rgb(255, 127, 14)',
@@ -35,7 +33,6 @@ DEFAULT_PLOTLY_COLORS = ['rgb(31, 119, 180)', 'rgb(255, 127, 14)',
                          'rgb(227, 119, 194)', 'rgb(127, 127, 127)',
                          'rgb(188, 189, 34)', 'rgb(23, 190, 207)']
 
-
 LineDataType = Tuple[str, 
                      pd.DataFrame, 
                      Dict[Any, pd.DataFrame]]
@@ -107,8 +104,10 @@ def simple_dimension_filter(data: pd.DataFrame, dim_name: str, selected_values:
     '''
     mask = np.full(len(data), True)
     for name, value in selected_values:
+        if value == 'All': continue
         mask &= (data[name] == value)
-    return np.unique(data[mask][dim_name].values)  # will sort values before returning them
+    values = np.unique(data[mask][dim_name].values)  # will sort values before returning them
+    return ['All'] + values.tolist()
     
     
 def simple_data_filter(data: pd.DataFrame, selected_values: List[Tuple[str, Any]]) -> pd.DataFrame:
@@ -117,6 +116,7 @@ def simple_data_filter(data: pd.DataFrame, selected_values: List[Tuple[str, Any]
     '''
     mask = np.full(len(data), True)
     for name, value in selected_values:
+        if value == 'All': continue
         mask &= (data[name] == value)
     return data[mask]
     
@@ -125,7 +125,7 @@ class MeanWithCI:
     '''
     Computes mean (or median) and optionally confidence intervals for plotting
     '''
-    def __init__(self, mean_func: Callable[[np.ndarray], np.ndarray] = np.mean, ci_level: int = 0) -> None:
+    def __init__(self, mean_func: Callable[[np.ndarray], np.ndarray] = np.nanmean, ci_level: int = 0) -> None:  # type: ignore
         '''
         Args:
             mean: The function to compute ci for
@@ -167,16 +167,22 @@ class SimpleDetailTable:
     Displays a pandas DataFrame under a plot that contains the data used to compute a statistic of y for each x, y pair
     '''
     
-    def __init__(self, colnames: Optional[List[str]] = None, float_format: str = '{:.4g}', min_rows: int = 100) -> None:
+    def __init__(self, 
+                 colnames: Optional[List[str]] = None, 
+                 float_format: str = '{:.4g}', 
+                 min_rows: int = 100, 
+                 copy_to_clipboard: bool = True) -> None:
         '''
         Args:
             colnames: List of column names to display. If None we display all columns. Default None
             float_format: Format for each floating point column. Default {:.4g}
             min_rows: Do not truncate the display of the table before this many rows. Default 100
+            copy_to_clipboard: If set, we copy the dataframe to the clipboard. On linux, you must install xclip for this to work
        '''
         self.colnames = colnames
         self.float_format = float_format
         self.min_rows = min_rows
+        self.copy_to_clipboard = True
         
     def __call__(self, detail_widget: widgets.Widget, data: pd.DataFrame) -> None:
         '''
@@ -195,7 +201,9 @@ class SimpleDetailTable:
         with detail_widget:
             clear_output()
             if self.colnames: data = data[self.colnames]
-            display(data.reset_index(drop=True))
+            data = data.reset_index(drop=True)
+            display(data)
+            if self.copy_to_clipboard: data.to_clipboard(index=False)
                 
         if self.float_format: pd.options.display.float_format = orig_float_format
         if self.min_rows: pd.options.display.min_rows = orig_min_rows
@@ -321,7 +329,7 @@ class LineGraphWithDetailDisplay:
                 unique, counts = np.unique(_detail_data[self.xcol].values, return_counts=True)
                 customdata = counts[np.searchsorted(unique, x)]
                 hovertemplate = 'N: %{customdata}'  # number of entries used to compute each x
-                hovertemplate += f' Series: {zvalue} {xaxis_title}: ' + '%{x} ' + f'{yaxis_title}: ' + '%{y:.2f}'
+                hovertemplate += f' Series: {zvalue} {xaxis_title}: ' + '%{x:.4g} ' + f'{yaxis_title}: ' + '%{y:.4g}'
                 
             trace = go.Scatter(
                 x=x,
@@ -479,6 +487,7 @@ class TestInteractivePlot(unittest.TestCase):
     def test_interactive_plot(self):
         np.random.seed(0)
         size = 1000
+        
         dte = np.random.randint(5, 10, size)
         put_call = np.random.choice(['put', 'call'], size)
         year = np.random.choice([2018, 2019, 2020, 2021], size)
@@ -486,6 +495,7 @@ class TestInteractivePlot(unittest.TestCase):
         delta = np.where(put_call == 'call', delta, -delta)
         premium = np.abs(delta * 10) * dte + np.random.normal(size=size) * dte / 10
         data = pd.DataFrame({'dte': dte, 'put_call': put_call, 'year': year, 'delta': delta, 'premium': premium})
+        
         labels = {'premium': 'Premium $', 'year': 'Year', 'dte': 'Days to Expiry', 'delta_rnd': 'Delta'}
         secy_line_config = LineConfig(secondary_y=True)
         
@@ -494,14 +504,15 @@ class TestInteractivePlot(unittest.TestCase):
                              transform_func=self.transform,
                              stat_func=MeanWithCI(ci_level=95),
                              plot_func=LineGraphWithDetailDisplay(line_configs={'put': secy_line_config}))
+        
         ip.create_pivot('delta_rnd', 'premium', 'put_call', dimensions={'year': 2018, 'dte': None})
     
     def transform(self, data: pd.DataFrame) -> pd.DataFrame:
-        data['delta_rnd'] = np.abs(np_bucket(data.delta, np.arange(-0.5, 0.6, 0.1)))
+        data['delta_rnd'] = percentile_buckets(np.abs(data.delta), 10)
         return data
     
       
 if __name__ == '__main__':
-    unittest.main(argv=['first-arg-is-ignored'], exit=False)
     doctest.testmod(optionflags=doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS)
+    unittest.main(argv=['first-arg-is-ignored'], exit=False)
     print('done')
